SlabBox

Struct SlabBox 

pub struct SlabBox<T, LOCK, const SLAB_SIZE: usize>
where LOCK: LockTrait,
{ /* private fields */ }
A smart pointer to an object of type T allocated in a slab.

When this struct goes out of scope, the memory is automatically returned to the originating slab.

Implementations

Source

impl<T, LOCK, const SLAB_SIZE: usize> SlabBox<T, LOCK, SLAB_SIZE>
where LOCK: LockTrait,

pub fn new(ptr: NonNull<T>) -> Self

Wraps a raw pointer into a SlabBox.

Safety
  • The ptr must be a valid, allocated slot from a Slab with SLAB_SIZE.
pub fn as_ptr(&self) -> *mut T

Returns the raw pointer to the underlying data.