pub struct SlabBox<T, LOCK, const SLAB_SIZE: usize>where
LOCK: LockTrait,{ /* private fields */ }Expand description
A smart pointer to an object of type T allocated in a slab.
When this struct goes out of scope, the memory is automatically returned to the originating slab.
Implementations